@@ -1,7 +1,7 @@
 """
 Put project's custom urls in this file
 """
-from django.conf.urls.defaults import *
+from django.conf.urls import *
 
 
 urlpatterns = patterns('',
